@@ -1,6 +1,6 @@
 /*
  * Strsed.c
- * $Id: strsed.c 68685 2010-06-10 11:45:54Z jmr@macports.org $
+ * $Id: strsed.c 120070 2014-05-14 22:27:37Z cal@macports.org $
  *
  *     ed(1)/tr(1)-like search, replace, transliterate. See the
  *     manpage for details. See the README for copyright information.
@@ -131,6 +131,9 @@
 
 #include "strsed.h"
 
+/* required for strdup(3) on Linux and OS X */
+#define _XOPEN_SOURCE 600L
+
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
@@ -662,7 +665,7 @@ int *range;
 
 	    if (need > 0){
 		more_space(need);
-		strncpy(new_str + new_pos, str, need);
+		memmove(new_str + new_pos, str, need);
 		new_pos += need;
 	    }
 
@@ -756,7 +759,7 @@ int *range;
      *
      */
     more_space(str_len);
-    (void) strcpy(new_str + new_pos, str);
+    (void) memmove(new_str + new_pos, str, strlen(str) + 1);
     RETURN(new_str);
 }
 
