@@ -1,6 +1,6 @@
 # et:ts=4
 # portchecksum.tcl
-# $Id: portchecksum.tcl 101265 2013-01-07 14:00:08Z jmr@macports.org $
+# $Id: portchecksum.tcl 117049 2014-02-14 00:15:07Z jmr@macports.org $
 #
 # Copyright (c) 2002 - 2004 Apple Inc.
 # Copyright (c) 2004 - 2005 Paul Guyot <pguyot@kallisys.net>
@@ -53,13 +53,13 @@ default checksum.skip false
 set_ui_prefix
 
 # The list of the types of checksums we know.
-set checksum_types "md5 sha1 rmd160 sha256"
+set checksum_types [list md5 sha1 rmd160 sha256 size]
 
 # The number of types we know.
 set checksum_types_count [llength $checksum_types]
 
 # types to recommend if none are specified in the portfile
-set default_checksum_types {rmd160 sha256}
+set default_checksum_types [list rmd160 sha256]
 
 # Using global all_dist_files, parse the checksums and store them into the
 # global array checksums_array.
@@ -82,8 +82,8 @@ proc portchecksum::parse_checksums {checksums_str} {
     set nb_checksum [llength $checksums_str]
 
     if {[llength $all_dist_files] == 1
-        && [expr $nb_checksum % 2] == 0
-        && [expr $nb_checksum / 2] <= $checksum_types_count
+        && [expr {$nb_checksum % 2}] == 0
+        && [expr {$nb_checksum / 2}] <= $checksum_types_count
         && [lsearch -exact $checksum_types [lindex $checksums_str 0]] >= 0} {
         # Convert to format #2
         set checksums_str [linsert $checksums_str 0 [lindex $all_dist_files 0]]
@@ -185,6 +185,15 @@ proc portchecksum::calc_sha256 {file} {
     return [sha256 file $file]
 }
 
+# calc_size
+#
+# Get the size of the given file.
+# Return the size.
+#
+proc portchecksum::calc_size {file} {
+    return [file size $file]
+}
+
 # checksum_start
 #
 # Target prerun procedure; simply prints a message about what we're doing.
@@ -192,7 +201,7 @@ proc portchecksum::calc_sha256 {file} {
 proc portchecksum::checksum_start {args} {
     global UI_PREFIX
 
-    ui_notice "$UI_PREFIX [format [msgcat::mc "Verifying checksum(s) for %s"] [option subport]]"
+    ui_notice "$UI_PREFIX [format [msgcat::mc "Verifying checksums for %s"] [option subport]]"
 }
 
 # checksum_main
@@ -200,8 +209,8 @@ proc portchecksum::checksum_start {args} {
 # Target main procedure. Verifies the checksums of all distfiles.
 #
 proc portchecksum::checksum_main {args} {
-    global UI_PREFIX all_dist_files checksum_types checksums_array portverbose checksum.skip
-    global usealtworkpath altprefix default_checksum_types
+    global UI_PREFIX all_dist_files checksum_types checksums_array portverbose checksum.skip \
+           usealtworkpath altprefix default_checksum_types
 
     # If no files have been downloaded, there is nothing to checksum.
     if {![info exists all_dist_files]} {
@@ -226,7 +235,7 @@ proc portchecksum::checksum_main {args} {
 
     # if everything is fine with the syntax, keep on and check the checksum of
     # the distfiles.
-    if {[parse_checksums $checksums_str] == "yes"} {
+    if {[parse_checksums $checksums_str] eq "yes"} {
         set distpath [option distpath]
 
         foreach distfile $all_dist_files {
@@ -264,7 +273,11 @@ proc portchecksum::checksum_main {args} {
                 foreach {type sum} $portfile_checksums {
                     set calculated_sum [calc_$type $fullpath]
                     lappend sums [format "%-8s%s" $type $calculated_sum]
-                    if {[string equal $sum $calculated_sum]} {
+
+		    # Used for regression testing
+                    ui_debug "[format [msgcat::mc "Calculated (%s) is %s"] $type $calculated_sum]"
+
+                    if {$sum eq $calculated_sum} {
                         ui_debug "[format [msgcat::mc "Correct (%s) checksum for %s"] $type $distfile]"
                     } else {
                         ui_error "[format [msgcat::mc "Checksum (%s) mismatch for %s"] $type $distfile]"
